# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

Name:		perl-Test2-Plugin-NoWarnings
Version:	0.10
Release:	1.%{__distinit}%{__distvers}
Summary:	Fail if tests warn
License:	Artistic-2.0
URL:		https://metacpan.org/release/Test2-Plugin-NoWarnings
Source0:	https://cpan.metacpan.org/authors/id/D/DR/DROLSKY/Test2-Plugin-NoWarnings-%{version}.tar.gz
BuildArch:	noarch
# Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	make
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
BuildRequires:	perl(ExtUtils::MakeMaker)
# Module Runtime
BuildRequires:	perl(Carp)
BuildRequires:	perl(parent)
BuildRequires:	perl(strict)
BuildRequires:	perl(Test2) >= 1.302167
BuildRequires:	perl(Test2::API)
BuildRequires:	perl(Test2::Event)
BuildRequires:	perl(Test2::Util::HashBase)
BuildRequires:	perl(warnings)
# Test Suite
BuildRequires:	perl(File::Spec)
BuildRequires:	perl(IPC::Run3)
BuildRequires:	perl(Module::Pluggable)
BuildRequires:	perl(Test2::Require::Module)
BuildRequires:	perl(Test2::V0)
BuildRequires:	perl(Test::More) >= 0.96
# Optional Tests
BuildRequires:	perl(CPAN::Meta) >= 2.120900
BuildRequires:	perl(CPAN::Meta::Prereqs)
# Dependencies
%if 0%{?fedora} < 38 && 0%{?rhel} < 10
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
%endif

%description
Loading this plugin causes your tests to fail if there are any warnings while
they run. Each warning generates a new failing test and the warning content is
outputted via diag.

This module uses $SIG{__WARN__}, so if the code you're testing sets this, then
this module will stop working.

%prep
%setup -q -n Test2-Plugin-NoWarnings-%{version}

%build
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%install
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
%{_fixperms} -c %{buildroot}

%check
make test

%files
%license LICENSE
%doc Changes CODE_OF_CONDUCT.md README.md
%{perl_vendorlib}/Test2/
%{_mandir}/man3/Test2::Event::Warning.3*
%{_mandir}/man3/Test2::Plugin::NoWarnings.3*

%changelog
* Sun Apr  7 2024 Paul Howarth <paul@city-fan.org> - 0.10-1
- Update to 0.10
  - Previously, when tests were run via prove without the verbose flag and
    there was a warning that caused a test failure, there was no output
    indicating that a warning caused the failure; this has now been corrected
    and you'll see output that includes "Unexpected warning"

* Wed May 17 2023 Paul Howarth <paul@city-fan.org> - 0.09-9
- Use SPDX-format license tag
- Use %%license unconditionally

* Tue Jun 30 2020 Paul Howarth <paul@city-fan.org> - 0.09-1
- Update to 0.09
  - Don't emit a failing test if there is a warning _after_ done_testing() is
    called (based on GH#3)

* Fri Oct 11 2019 Paul Howarth <paul@city-fan.org> - 0.08-1
- Update to 0.08
  - Use IPC::Run3 instead of Capture::Tiny for all tests, which fixes an issue
    with the 'tap-bug-in-test2.t' on Windows (CPAN RT#129294)

* Fri Jun  7 2019 Paul Howarth <paul@city-fan.org> - 0.07-2
- Perl 5.30 rebuild

* Mon Apr 22 2019 Paul Howarth <paul@city-fan.org> - 0.07-1
- Update to 0.07
  - Reverted back to using the Warning event type, since the bug in the Test2
    core that caused this to be a problem has since been fixed
  - Replaced use of Test2::Bundle::Extended with Test2::V0
- Package new document CODE_OF_CONDUCT.md

* Wed Apr 11 2018 Paul Howarth <paul@city-fan.org> - 0.06-3
- BR: perl-generators unconditionally
- BR: perl-interpreter rather than perl

* Mon Jun 19 2017 Paul Howarth <paul@city-fan.org> - 0.06-1
- Update to 0.06
  - Warnings inside a subtest were not emitted as TAP events, breaking the TAP
    and making for great confusion: this is because of a bug in the core TAP
    formatter (https://github.com/Test-More/test-more/issues/776); warnings
    are now emitted as Ok events instead of Warning events
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section

* Tue Nov  8 2016 Paul Howarth <paul@city-fan.org> - 0.05-1
- Update to 0.05
  - Skip compile.t on Windows; this test uses IPC::Run3, which doesn't seem to
    work well on that platform (CPAN RT#118443)

* Thu Oct 27 2016 Paul Howarth <paul@city-fan.org> - 0.04-2
- We provide Test2::Event::Warning so we don't need to build-require it

* Mon Oct 24 2016 Paul Howarth <paul@city-fan.org> - 0.04-1
- Update to 0.04
  - Load Test2::Event::Warning in the plugin instead of relying on Test2 to do
    it for us; this should avoid the bug fixed in the previous version and
    eliminates the need for the INIT block, which caused its own problems

* Tue Oct 18 2016 Paul Howarth <paul@city-fan.org> - 0.03-1
- Update to 0.03
  - Add the $SIG{__WARN__} hook in an INIT block; we really don't want to
    trigger this because of a compile-time warning, and because of a bug in
    Test::Builder, this can actually cause the warning to be lost entirely
    (https://github.com/Test-More/test-more/issues/729)
  - The Test2::Event::Warning event now returns true for increments_count,
    which means that the test failure caused by a warning will not be output
    as a TAP test line; previously this was just seen as a diag line, which
    could be quite confusing
    (https://github.com/Test-More/test-more/issues/728)

* Sun Sep 18 2016 Paul Howarth <paul@city-fan.org> - 0.02-1
- Initial RPM version
